/**
******************************************************************************
* @file     main.c
* @author   AE team
* @version  V1.0.8
* @date     10/04/2019
* @brief
******************************************************************************
* @copy
*
* THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
* TIME. AS A RESULT, MindMotion SHALL NOT BE HELD LIABLE FOR ANY
* DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
* FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
* CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*
* <h2><center>&copy; COPYRIGHT 2019 MindMotion</center></h2>
*/
#include "HAL_device.h"
#include "HAL_conf.h"
#include "stdio.h"

extern u32 SystemCoreClock;
void delay_init(void);
void delay_ms(__IO uint32_t nTime);
void TimingDelay_Decrement(void);
void LED_Init(void);
void KEY_Init(void);
void EXTIX_Init(void);



static __IO uint32_t TimingDelay;

#define LED1_Port  GPIOA
#define LED1_Pin   GPIO_Pin_4
#define LED1_ON()  GPIO_ResetBits(LED1_Port,LED1_Pin)
#define LED1_OFF()  GPIO_SetBits(LED1_Port,LED1_Pin)
#define LED1_TOGGLE()  (GPIO_ReadOutputDataBit(LED1_Port,LED1_Pin))?(GPIO_ResetBits(LED1_Port,LED1_Pin)):(GPIO_SetBits(LED1_Port,LED1_Pin))

#define KEY1_Port  GPIOA
#define KEY1_Pin   GPIO_Pin_5

#define KEY1  GPIO_ReadInputDataBit(KEY1_Port,KEY1_Pin)//ȡ1



/********************************************************************************************************
**Ϣ main(void)
** 
** 
** 
********************************************************************************************************/
int main(void)
{
    delay_init();
    LED_Init();
    KEY_Init();
    EXTIX_Init();
    while(1) {
    }
}

/********************************************************************************************************
**Ϣ delay_init(void)
** systickʱʼ
** 
** 
********************************************************************************************************/
void delay_init(void)
{
    if (SysTick_Config(SystemCoreClock / 1000)) {
        /* Capture error */
        while (1);
    }
    /* Configure the SysTick handler priority */
    NVIC_SetPriority(SysTick_IRQn, 0x0);                                        //SysTickжȼ
}

/********************************************************************************************************
**Ϣ SysTick_Handler(void)
** жϺSystickеݼ
** 
** 
********************************************************************************************************/
void SysTick_Handler(void)
{
    TimingDelay_Decrement();
}

/********************************************************************************************************
**Ϣ TimingDelay_Decrement(void)
** 1msٶȵݼ
** pclk2ϵͳʱΪ8MHzӦ8
** 
********************************************************************************************************/
void TimingDelay_Decrement(void)
{
    if (TimingDelay != 0x00) {
        TimingDelay--;
    }
}

/********************************************************************************************************
**Ϣ delay_ms(__IO uint32_t nTime)
** Ӧõʱʹsystick
** nTimeʱ
** 
********************************************************************************************************/
void delay_ms(__IO uint32_t nTime)
{
    TimingDelay = nTime;

    while(TimingDelay != 0);
}

/*******************************************************************************
* @name   : GPIO_Clock_Set
* @brief  : RCC clock set
* @param  : Portx , State
* @retval : void
*******************************************************************************/
void GPIO_Clock_Set(GPIO_TypeDef* GPIOx, FunctionalState NewState)
{

    if(GPIOx == GPIOA) {
        RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, NewState);                         //GPIO clock starts
    }
    if(GPIOx == GPIOB) {
        RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOB, NewState);                         //GPIO clock starts
    }
    if(GPIOx == GPIOC) {
        RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, NewState);                         //GPIO clock starts
    }
    if(GPIOx == GPIOD) {
        RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOD, NewState);                         //GPIO clock starts
    }
}
/********************************************************************************************************
**Ϣ LED_Init(void)
** LEDʼ
** 
** 
********************************************************************************************************/
void LED_Init(void)
{

    GPIO_InitTypeDef  GPIO_InitStructure;

    GPIO_Clock_Set(LED1_Port, ENABLE);  //GPIOAʱ

    GPIO_InitStructure.GPIO_Pin  =  LED1_Pin;
    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
    GPIO_Init(LED1_Port, &GPIO_InitStructure);


    LED1_OFF();

}

/********************************************************************************************************
**Ϣ void KEY_Init(void)
** ʼ
** 
** 
**    ע 
********************************************************************************************************/
void KEY_Init(void)
{
    GPIO_InitTypeDef GPIO_InitStructure;

    GPIO_Clock_Set(KEY1_Port, ENABLE);  //KEY1 GPIO Port ʱ


    GPIO_InitStructure.GPIO_Pin  = KEY1_Pin;                                    // K1
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPU;//GPIO_Mode_IN_FLOATING;                       //ó
    GPIO_Init(KEY1_Port, &GPIO_InitStructure);                                  //ʼGPIOA5
    GPIO_SetBits(KEY1_Port, KEY1_Pin);
}

/********************************************************************************************************
**Ϣ void EXTIX_Init(void)
** ⲿжϳʼ
** 
** 
**ú 
********************************************************************************************************/
void EXTIX_Init(void)
{
    EXTI_InitTypeDef EXTI_InitStructure;
    NVIC_InitTypeDef NVIC_InitStructure;

    RCC_APB2PeriphClockCmd(RCC_APB2Periph_SYSCFG, ENABLE);                      //ⲿжϣҪʹAFIOʱ

    KEY_Init();                                                                 //ʼӦioģʽ


    //GPIOA.0	  жԼжϳʼ
    SYSCFG_EXTILineConfig(EXTI_PortSourceGPIOA, EXTI_PinSource5);

    EXTI_InitStructure.EXTI_Line = EXTI_Line5;
    EXTI_InitStructure.EXTI_Mode = EXTI_Mode_Interrupt;
    EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Falling;                      //½ش
    EXTI_InitStructure.EXTI_LineCmd = ENABLE;
    EXTI_Init(&EXTI_InitStructure);                                             //EXTI_InitStructָĲʼEXTIĴ

    NVIC_InitStructure.NVIC_IRQChannel = EXTI4_15_IRQn;                          //ʹܰڵⲿжͨ
    NVIC_InitStructure.NVIC_IRQChannelPriority = 0x01;                          //ȼ1
    NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;                             //ʹⲿжͨ
    NVIC_Init(&NVIC_InitStructure);

}

/********************************************************************************************************
**Ϣ void EXTI0_1_IRQHandler(void)
** ⲿжϺ
** 
** 
**ú 
********************************************************************************************************/
u16 EXTI_DELAY = 0;

void EXTI4_15_IRQHandler(void)
{
    for(EXTI_DELAY = 0; EXTI_DELAY < 1000; EXTI_DELAY++);
    if(KEY1 == 0) {
        LED1_TOGGLE();
    }
    EXTI_ClearFlag(EXTI_Line5);                                                 //EXTI5·λ
}


/**
* @}
*/

/**
* @}
*/

/**
* @}
*/

/*-------------------------(C) COPYRIGHT 2019 MindMotion ----------------------*/

